@@ -351,7 +351,7 @@ class TestCoroutines:
     @patch("apologiesserver.server._handle_data")
     async def test_handle_connection_shutdown(self, handle_data, handle_exception, handle_connect, handle_disconnect):
         websocket = AsyncMock()
-        exception = ConnectionClosed(1, "reason")
+        exception = ConnectionClosed(None, None)
         websocket.__aiter__.side_effect = exception  # the wait on the websocket is what throws the connection closed
         handle_data.side_effect = exception
         await _handle_connection(websocket, "path")  # path is unused
@@ -374,7 +374,7 @@ class TestCoroutines:
 
     @patch("apologiesserver.server._handle_shutdown")
     @patch("apologiesserver.server._handle_connection")
-    @patch("apologiesserver.server.websockets.serve")
+    @patch("apologiesserver.server.serve")
     async def test_websocket_server(self, serve, handle_connection, handle_shutdown):
         stop = asyncio.Future()
         stop.set_result(None)
